IsolateConstantManager class

Manager for accessing constants in isolates Constants are initialized once in the main thread and passed to isolates

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getAllConstants() Map<String, dynamic>
Get all constants as a map
getConstant<T>(String key) → T?
Get a constant by key
getConstantCount() int
Get the number of available constants
getConstantKeys() List<String>
Get all available constant keys
hasConstant(String key) bool
Check if a constant exists
initializeConstants(Map<String, dynamic> constants) → void
Initialize constants in the isolate