IsolateMessage class
Message structure for isolate communication
Constructors
- IsolateMessage({required MessageType type, String? taskId, dynamic data, dynamic error})
Properties
- data → dynamic
-
final
- error → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskId → String?
-
final
- type → MessageType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromMap(
Map< String, dynamic> map) → IsolateMessage