IsolateResourceManager class
Manager for isolate resources with proper cleanup
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
clearResources(
) → void - Clear all resources without calling finalizers (use with caution)
-
finalizeAllResources(
) → Future< void> - Clean up all resources using their finalizers
-
getResource<
T> (String key) → T? - Get a resource by key with type safety
-
getResourceCount(
) → int - Get resource count
-
getResourceKeys(
) → List< String> - Get all resource keys
-
hasResource(
String key) → bool - Check if a resource exists
-
storeResource(
String key, dynamic resource, [ResourceFinalizer? finalizer]) → void - Store a resource with the given key and optional finalizer